#[repr(u8)]pub enum InterruptMode {
Disabled = 0,
Legacy = 1,
LegacyNoack = 2,
Msi = 3,
MsiX = 4,
UnknownOrdinal_(u8),
}Expand description
Used with ||SetInterruptMode| to configure an interrupt mode for the device. Devices configured to use the LEGACY Irq mode must ack their interrupt after servicing by calling |AckInterrupt|. To avoid this, LEGACY_NOACK can be used, but the driver’s interrupt function will be disabled by the PCI Bus Driver if it sees excessive interrupt triggers in a given period.
Variants