pub struct Bar {
pub bar_id: u32,
pub size: u64,
pub result: BarResult,
}Expand description
Describes and provides access to a given Base Address Register for the device.
Fields
bar_id: u32size: u64result: BarResultTrait Implementations
Sourceimpl<___E> Encode<Bar<'static>, ___E> for Barwhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
impl<___E> Encode<Bar<'static>, ___E> for Barwhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
Sourceimpl<___E> EncodeOption<Box<'static, Bar<'static>>, ___E> for Bar
impl<___E> EncodeOption<Box<'static, Bar<'static>>, ___E> for Bar
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Bar<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Bar<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl StructuralPartialEq for Bar