pub struct BusGetHostBridgeInfoResponse {
pub info: HostBridgeInfo,
}Fields
info: HostBridgeInfoTrait Implementations
Sourceimpl Clone for BusGetHostBridgeInfoResponse
impl Clone for BusGetHostBridgeInfoResponse
Sourcefn clone(&self) -> BusGetHostBridgeInfoResponse
fn clone(&self) -> BusGetHostBridgeInfoResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BusGetHostBridgeInfoResponse
impl Debug for BusGetHostBridgeInfoResponse
Sourceimpl<'a, ___E> Encode<BusGetHostBridgeInfoResponse<'static>, ___E> for &'a BusGetHostBridgeInfoResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<BusGetHostBridgeInfoResponse<'static>, ___E> for &'a BusGetHostBridgeInfoResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<BusGetHostBridgeInfoResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<BusGetHostBridgeInfoResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<BusGetHostBridgeInfoResponse<'static>, ___E> for BusGetHostBridgeInfoResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<BusGetHostBridgeInfoResponse<'static>, ___E> for BusGetHostBridgeInfoResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<BusGetHostBridgeInfoResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<BusGetHostBridgeInfoResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, BusGetHostBridgeInfoResponse<'static>>, ___E> for &'a BusGetHostBridgeInfoResponsewhere
___E: Encoder + ?Sized,
&'a BusGetHostBridgeInfoResponse: Encode<BusGetHostBridgeInfoResponse<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, BusGetHostBridgeInfoResponse<'static>>, ___E> for &'a BusGetHostBridgeInfoResponsewhere
___E: Encoder + ?Sized,
&'a BusGetHostBridgeInfoResponse: Encode<BusGetHostBridgeInfoResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a BusGetHostBridgeInfoResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, BusGetHostBridgeInfoResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a BusGetHostBridgeInfoResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, BusGetHostBridgeInfoResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, BusGetHostBridgeInfoResponse<'static>>, ___E> for BusGetHostBridgeInfoResponsewhere
___E: Encoder + ?Sized,
BusGetHostBridgeInfoResponse: Encode<BusGetHostBridgeInfoResponse<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, BusGetHostBridgeInfoResponse<'static>>, ___E> for BusGetHostBridgeInfoResponsewhere
___E: Encoder + ?Sized,
BusGetHostBridgeInfoResponse: Encode<BusGetHostBridgeInfoResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<BusGetHostBridgeInfoResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, BusGetHostBridgeInfoResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<BusGetHostBridgeInfoResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, BusGetHostBridgeInfoResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<BusGetHostBridgeInfoResponse<'de>> for BusGetHostBridgeInfoResponse
impl<'de> FromWire<BusGetHostBridgeInfoResponse<'de>> for BusGetHostBridgeInfoResponse
Sourcefn from_wire(
wire: BusGetHostBridgeInfoResponse<'de>,
) -> BusGetHostBridgeInfoResponse
fn from_wire( wire: BusGetHostBridgeInfoResponse<'de>, ) -> BusGetHostBridgeInfoResponse
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<BusGetHostBridgeInfoResponse<'de>> for BusGetHostBridgeInfoResponse
impl<'de> FromWireRef<BusGetHostBridgeInfoResponse<'de>> for BusGetHostBridgeInfoResponse
Sourcefn from_wire_ref(
wire: &BusGetHostBridgeInfoResponse<'de>,
) -> BusGetHostBridgeInfoResponse
fn from_wire_ref( wire: &BusGetHostBridgeInfoResponse<'de>, ) -> BusGetHostBridgeInfoResponse
Converts the given reference to this type.
Sourceimpl Hash for BusGetHostBridgeInfoResponse
impl Hash for BusGetHostBridgeInfoResponse
Sourceimpl Ord for BusGetHostBridgeInfoResponse
impl Ord for BusGetHostBridgeInfoResponse
Sourcefn cmp(&self, other: &BusGetHostBridgeInfoResponse) -> Ordering
fn cmp(&self, other: &BusGetHostBridgeInfoResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for BusGetHostBridgeInfoResponse
impl PartialEq for BusGetHostBridgeInfoResponse
Sourcefn eq(&self, other: &BusGetHostBridgeInfoResponse) -> bool
fn eq(&self, other: &BusGetHostBridgeInfoResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for BusGetHostBridgeInfoResponse
impl PartialOrd for BusGetHostBridgeInfoResponse
impl Eq for BusGetHostBridgeInfoResponse
impl StructuralPartialEq for BusGetHostBridgeInfoResponse