pub struct DeviceGetBarResponse {
pub result: Bar,
}Fields
result: BarTrait Implementations
Sourceimpl Debug for DeviceGetBarResponse
impl Debug for DeviceGetBarResponse
Sourceimpl<___E> Encode<DeviceGetBarResponse<'static>, ___E> for DeviceGetBarResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
impl<___E> Encode<DeviceGetBarResponse<'static>, ___E> for DeviceGetBarResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetBarResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetBarResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, DeviceGetBarResponse<'static>>, ___E> for DeviceGetBarResponse
impl<___E> EncodeOption<Box<'static, DeviceGetBarResponse<'static>>, ___E> for DeviceGetBarResponse
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetBarResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetBarResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<DeviceGetBarResponse<'de>> for DeviceGetBarResponse
impl<'de> FromWire<DeviceGetBarResponse<'de>> for DeviceGetBarResponse
Sourcefn from_wire(wire: DeviceGetBarResponse<'de>) -> Self
fn from_wire(wire: DeviceGetBarResponse<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl PartialEq for DeviceGetBarResponse
impl PartialEq for DeviceGetBarResponse
Sourcefn eq(&self, other: &DeviceGetBarResponse) -> bool
fn eq(&self, other: &DeviceGetBarResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DeviceGetBarResponse