#[repr(C)]pub struct DeviceGetBtiResponse {
pub bti: Bti,
}Fields
bti: BtiTrait Implementations
Sourceimpl Debug for DeviceGetBtiResponse
impl Debug for DeviceGetBtiResponse
Sourceimpl<___E> Encode<DeviceGetBtiResponse, ___E> for DeviceGetBtiResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<DeviceGetBtiResponse, ___E> for DeviceGetBtiResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetBtiResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetBtiResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetBtiResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetBtiResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, DeviceGetBtiResponse>, ___E> for DeviceGetBtiResponse
impl<___E> EncodeOption<Box<'static, DeviceGetBtiResponse>, ___E> for DeviceGetBtiResponse
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetBtiResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetBtiResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<DeviceGetBtiResponse> for DeviceGetBtiResponse
impl FromWire<DeviceGetBtiResponse> for DeviceGetBtiResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetBtiResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetBtiResponse, Self>
Sourcefn from_wire(wire: DeviceGetBtiResponse) -> Self
fn from_wire(wire: DeviceGetBtiResponse) -> Self
Converts the given owned value to this type.
Sourceimpl PartialEq for DeviceGetBtiResponse
impl PartialEq for DeviceGetBtiResponse
Sourcefn eq(&self, other: &DeviceGetBtiResponse) -> bool
fn eq(&self, other: &DeviceGetBtiResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DeviceGetBtiResponse