#[repr(C)]pub struct DeviceMapInterruptResponse {
pub interrupt: Interrupt,
}Fields
interrupt: InterruptTrait Implementations
Sourceimpl Debug for DeviceMapInterruptResponse
impl Debug for DeviceMapInterruptResponse
Sourceimpl<___E> Encode<DeviceMapInterruptResponse, ___E> for DeviceMapInterruptResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<DeviceMapInterruptResponse, ___E> for DeviceMapInterruptResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceMapInterruptResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceMapInterruptResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceMapInterruptResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceMapInterruptResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, DeviceMapInterruptResponse>, ___E> for DeviceMapInterruptResponse
impl<___E> EncodeOption<Box<'static, DeviceMapInterruptResponse>, ___E> for DeviceMapInterruptResponse
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceMapInterruptResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceMapInterruptResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<DeviceMapInterruptResponse> for DeviceMapInterruptResponse
impl FromWire<DeviceMapInterruptResponse> for DeviceMapInterruptResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceMapInterruptResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceMapInterruptResponse, Self>
Sourcefn from_wire(wire: DeviceMapInterruptResponse) -> Self
fn from_wire(wire: DeviceMapInterruptResponse) -> Self
Converts the given owned value to this type.
Sourceimpl PartialEq for DeviceMapInterruptResponse
impl PartialEq for DeviceMapInterruptResponse
Sourcefn eq(&self, other: &DeviceMapInterruptResponse) -> bool
fn eq(&self, other: &DeviceMapInterruptResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DeviceMapInterruptResponse