#[repr(C)]pub struct InterruptModes {
pub has_legacy: bool,
pub msi_count: u8,
pub msix_count: u16,
}Expand description
Returned by |GetInterruptModes|. Contains the number of interrupts supported by a given PCI device interrupt mode. 0 is returned for a mode if unsupported.
Fields
has_legacy: boolmsi_count: u8msix_count: u16Trait Implementations
Sourceimpl Clone for InterruptModes
impl Clone for InterruptModes
Sourcefn clone(&self) -> InterruptModes
fn clone(&self) -> InterruptModes
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InterruptModes
impl Debug for InterruptModes
Sourceimpl<'a, ___E> Encode<InterruptModes, ___E> for &'a InterruptModeswhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<InterruptModes, ___E> for &'a InterruptModeswhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InterruptModes>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InterruptModes>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<InterruptModes, ___E> for InterruptModeswhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<InterruptModes, ___E> for InterruptModeswhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<InterruptModes, InterruptModes>
const COPY_OPTIMIZATION: CopyOptimization<InterruptModes, InterruptModes>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InterruptModes>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InterruptModes>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, InterruptModes>, ___E> for &'a InterruptModes
impl<'a, ___E> EncodeOption<Box<'static, InterruptModes>, ___E> for &'a InterruptModes
Sourcefn encode_option(
this: Option<&'a InterruptModes>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, InterruptModes>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a InterruptModes>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, InterruptModes>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, InterruptModes>, ___E> for InterruptModes
impl<___E> EncodeOption<Box<'static, InterruptModes>, ___E> for InterruptModes
Sourcefn encode_option(
this: Option<InterruptModes>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, InterruptModes>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<InterruptModes>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, InterruptModes>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<InterruptModes> for InterruptModes
impl FromWire<InterruptModes> for InterruptModes
Sourceconst COPY_OPTIMIZATION: CopyOptimization<InterruptModes, InterruptModes>
const COPY_OPTIMIZATION: CopyOptimization<InterruptModes, InterruptModes>
Sourcefn from_wire(wire: InterruptModes) -> InterruptModes
fn from_wire(wire: InterruptModes) -> InterruptModes
Converts the given owned value to this type.
Sourceimpl FromWireRef<InterruptModes> for InterruptModes
impl FromWireRef<InterruptModes> for InterruptModes
Sourcefn from_wire_ref(wire: &InterruptModes) -> InterruptModes
fn from_wire_ref(wire: &InterruptModes) -> InterruptModes
Converts the given reference to this type.
Sourceimpl Hash for InterruptModes
impl Hash for InterruptModes
Sourceimpl Ord for InterruptModes
impl Ord for InterruptModes
Sourcefn cmp(&self, other: &InterruptModes) -> Ordering
fn cmp(&self, other: &InterruptModes) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for InterruptModes
impl PartialEq for InterruptModes
Sourcefn eq(&self, other: &InterruptModes) -> bool
fn eq(&self, other: &InterruptModes) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for InterruptModes
impl PartialOrd for InterruptModes
impl Copy for InterruptModes
impl Eq for InterruptModes
impl StructuralPartialEq for InterruptModes