pub struct BaseAddress {
pub address: u64,
pub size: u64,
pub is_memory: bool,
pub is_prefetchable: bool,
pub is_64bit: bool,
pub id: u8,
}Fields
address: u64size: u64is_memory: boolis_prefetchable: boolis_64bit: boolid: u8Trait Implementations
Sourceimpl Clone for BaseAddress
impl Clone for BaseAddress
Sourcefn clone(&self) -> BaseAddress
fn clone(&self) -> BaseAddress
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BaseAddress
impl Debug for BaseAddress
Sourceimpl<'a, ___E> Encode<BaseAddress, ___E> for &'a BaseAddresswhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<BaseAddress, ___E> for &'a BaseAddresswhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<BaseAddress>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<BaseAddress>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<BaseAddress, ___E> for BaseAddresswhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<BaseAddress, ___E> for BaseAddresswhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<BaseAddress>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<BaseAddress>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, BaseAddress>, ___E> for &'a BaseAddress
impl<'a, ___E> EncodeOption<Box<'static, BaseAddress>, ___E> for &'a BaseAddress
Sourcefn encode_option(
this: Option<&'a BaseAddress>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, BaseAddress>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a BaseAddress>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, BaseAddress>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, BaseAddress>, ___E> for BaseAddress
impl<___E> EncodeOption<Box<'static, BaseAddress>, ___E> for BaseAddress
Sourcefn encode_option(
this: Option<BaseAddress>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, BaseAddress>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<BaseAddress>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, BaseAddress>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<BaseAddress> for BaseAddress
impl FromWire<BaseAddress> for BaseAddress
Sourcefn from_wire(wire: BaseAddress) -> BaseAddress
fn from_wire(wire: BaseAddress) -> BaseAddress
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<BaseAddress> for BaseAddress
impl FromWireRef<BaseAddress> for BaseAddress
Sourcefn from_wire_ref(wire: &BaseAddress) -> BaseAddress
fn from_wire_ref(wire: &BaseAddress) -> BaseAddress
Converts the given reference to this type.
Sourceimpl Hash for BaseAddress
impl Hash for BaseAddress
Sourceimpl Ord for BaseAddress
impl Ord for BaseAddress
Sourcefn cmp(&self, other: &BaseAddress) -> Ordering
fn cmp(&self, other: &BaseAddress) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for BaseAddress
impl PartialEq for BaseAddress
Sourcefn eq(&self, other: &BaseAddress) -> bool
fn eq(&self, other: &BaseAddress) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for BaseAddress
impl PartialOrd for BaseAddress
impl Copy for BaseAddress
impl Eq for BaseAddress
impl StructuralPartialEq for BaseAddress