#[repr(C)]pub struct DeviceGetDeviceInfoResponse {
pub info: DeviceInfo,
}Fields
info: DeviceInfoTrait Implementations
Sourceimpl Clone for DeviceGetDeviceInfoResponse
impl Clone for DeviceGetDeviceInfoResponse
Sourcefn clone(&self) -> DeviceGetDeviceInfoResponse
fn clone(&self) -> DeviceGetDeviceInfoResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeviceGetDeviceInfoResponse
impl Debug for DeviceGetDeviceInfoResponse
Sourceimpl<'a, ___E> Encode<DeviceGetDeviceInfoResponse, ___E> for &'a DeviceGetDeviceInfoResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceGetDeviceInfoResponse, ___E> for &'a DeviceGetDeviceInfoResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetDeviceInfoResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetDeviceInfoResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceGetDeviceInfoResponse, ___E> for DeviceGetDeviceInfoResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceGetDeviceInfoResponse, ___E> for DeviceGetDeviceInfoResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetDeviceInfoResponse, DeviceGetDeviceInfoResponse>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetDeviceInfoResponse, DeviceGetDeviceInfoResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetDeviceInfoResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetDeviceInfoResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, DeviceGetDeviceInfoResponse>, ___E> for &'a DeviceGetDeviceInfoResponsewhere
___E: Encoder + ?Sized,
&'a DeviceGetDeviceInfoResponse: Encode<DeviceGetDeviceInfoResponse, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, DeviceGetDeviceInfoResponse>, ___E> for &'a DeviceGetDeviceInfoResponsewhere
___E: Encoder + ?Sized,
&'a DeviceGetDeviceInfoResponse: Encode<DeviceGetDeviceInfoResponse, ___E>,
Sourcefn encode_option(
this: Option<&'a DeviceGetDeviceInfoResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetDeviceInfoResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a DeviceGetDeviceInfoResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetDeviceInfoResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, DeviceGetDeviceInfoResponse>, ___E> for DeviceGetDeviceInfoResponsewhere
___E: Encoder + ?Sized,
DeviceGetDeviceInfoResponse: Encode<DeviceGetDeviceInfoResponse, ___E>,
impl<___E> EncodeOption<Box<'static, DeviceGetDeviceInfoResponse>, ___E> for DeviceGetDeviceInfoResponsewhere
___E: Encoder + ?Sized,
DeviceGetDeviceInfoResponse: Encode<DeviceGetDeviceInfoResponse, ___E>,
Sourcefn encode_option(
this: Option<DeviceGetDeviceInfoResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetDeviceInfoResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<DeviceGetDeviceInfoResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetDeviceInfoResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<DeviceGetDeviceInfoResponse> for DeviceGetDeviceInfoResponse
impl FromWire<DeviceGetDeviceInfoResponse> for DeviceGetDeviceInfoResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetDeviceInfoResponse, DeviceGetDeviceInfoResponse>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetDeviceInfoResponse, DeviceGetDeviceInfoResponse>
Sourcefn from_wire(wire: DeviceGetDeviceInfoResponse) -> DeviceGetDeviceInfoResponse
fn from_wire(wire: DeviceGetDeviceInfoResponse) -> DeviceGetDeviceInfoResponse
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceGetDeviceInfoResponse> for DeviceGetDeviceInfoResponse
impl FromWireRef<DeviceGetDeviceInfoResponse> for DeviceGetDeviceInfoResponse
Sourcefn from_wire_ref(
wire: &DeviceGetDeviceInfoResponse,
) -> DeviceGetDeviceInfoResponse
fn from_wire_ref( wire: &DeviceGetDeviceInfoResponse, ) -> DeviceGetDeviceInfoResponse
Converts the given reference to this type.
Sourceimpl Hash for DeviceGetDeviceInfoResponse
impl Hash for DeviceGetDeviceInfoResponse
Sourceimpl Ord for DeviceGetDeviceInfoResponse
impl Ord for DeviceGetDeviceInfoResponse
Sourcefn cmp(&self, other: &DeviceGetDeviceInfoResponse) -> Ordering
fn cmp(&self, other: &DeviceGetDeviceInfoResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeviceGetDeviceInfoResponse
impl PartialEq for DeviceGetDeviceInfoResponse
Sourcefn eq(&self, other: &DeviceGetDeviceInfoResponse) -> bool
fn eq(&self, other: &DeviceGetDeviceInfoResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DeviceGetDeviceInfoResponse
impl PartialOrd for DeviceGetDeviceInfoResponse
impl Copy for DeviceGetDeviceInfoResponse
impl Eq for DeviceGetDeviceInfoResponse
impl StructuralPartialEq for DeviceGetDeviceInfoResponse