#[repr(C)]pub struct DeviceReadConfig32Response {
pub value: u32,
}Fields
value: u32Trait Implementations
Sourceimpl Clone for DeviceReadConfig32Response
impl Clone for DeviceReadConfig32Response
Sourcefn clone(&self) -> DeviceReadConfig32Response
fn clone(&self) -> DeviceReadConfig32Response
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeviceReadConfig32Response
impl Debug for DeviceReadConfig32Response
Sourceimpl<'a, ___E> Encode<DeviceReadConfig32Response, ___E> for &'a DeviceReadConfig32Responsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceReadConfig32Response, ___E> for &'a DeviceReadConfig32Responsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceReadConfig32Response>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceReadConfig32Response>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceReadConfig32Response, ___E> for DeviceReadConfig32Responsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceReadConfig32Response, ___E> for DeviceReadConfig32Responsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceReadConfig32Response, DeviceReadConfig32Response>
const COPY_OPTIMIZATION: CopyOptimization<DeviceReadConfig32Response, DeviceReadConfig32Response>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceReadConfig32Response>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceReadConfig32Response>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, DeviceReadConfig32Response>, ___E> for &'a DeviceReadConfig32Responsewhere
___E: Encoder + ?Sized,
&'a DeviceReadConfig32Response: Encode<DeviceReadConfig32Response, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, DeviceReadConfig32Response>, ___E> for &'a DeviceReadConfig32Responsewhere
___E: Encoder + ?Sized,
&'a DeviceReadConfig32Response: Encode<DeviceReadConfig32Response, ___E>,
Sourcefn encode_option(
this: Option<&'a DeviceReadConfig32Response>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceReadConfig32Response>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a DeviceReadConfig32Response>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceReadConfig32Response>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, DeviceReadConfig32Response>, ___E> for DeviceReadConfig32Response
impl<___E> EncodeOption<Box<'static, DeviceReadConfig32Response>, ___E> for DeviceReadConfig32Response
Sourcefn encode_option(
this: Option<DeviceReadConfig32Response>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceReadConfig32Response>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<DeviceReadConfig32Response>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceReadConfig32Response>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<DeviceReadConfig32Response> for DeviceReadConfig32Response
impl FromWire<DeviceReadConfig32Response> for DeviceReadConfig32Response
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceReadConfig32Response, DeviceReadConfig32Response>
const COPY_OPTIMIZATION: CopyOptimization<DeviceReadConfig32Response, DeviceReadConfig32Response>
Sourcefn from_wire(wire: DeviceReadConfig32Response) -> DeviceReadConfig32Response
fn from_wire(wire: DeviceReadConfig32Response) -> DeviceReadConfig32Response
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceReadConfig32Response> for DeviceReadConfig32Response
impl FromWireRef<DeviceReadConfig32Response> for DeviceReadConfig32Response
Sourcefn from_wire_ref(
wire: &DeviceReadConfig32Response,
) -> DeviceReadConfig32Response
fn from_wire_ref( wire: &DeviceReadConfig32Response, ) -> DeviceReadConfig32Response
Converts the given reference to this type.
Sourceimpl Hash for DeviceReadConfig32Response
impl Hash for DeviceReadConfig32Response
Sourceimpl Ord for DeviceReadConfig32Response
impl Ord for DeviceReadConfig32Response
Sourcefn cmp(&self, other: &DeviceReadConfig32Response) -> Ordering
fn cmp(&self, other: &DeviceReadConfig32Response) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeviceReadConfig32Response
impl PartialEq for DeviceReadConfig32Response
Sourcefn eq(&self, other: &DeviceReadConfig32Response) -> bool
fn eq(&self, other: &DeviceReadConfig32Response) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DeviceReadConfig32Response
impl PartialOrd for DeviceReadConfig32Response
impl Copy for DeviceReadConfig32Response
impl Eq for DeviceReadConfig32Response
impl StructuralPartialEq for DeviceReadConfig32Response