#[repr(C)]pub struct DeviceReadConfig8Response {
pub value: u8,
}Fields
value: u8Trait Implementations
Sourceimpl Clone for DeviceReadConfig8Response
impl Clone for DeviceReadConfig8Response
Sourcefn clone(&self) -> DeviceReadConfig8Response
fn clone(&self) -> DeviceReadConfig8Response
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeviceReadConfig8Response
impl Debug for DeviceReadConfig8Response
Sourceimpl<'a, ___E> Encode<DeviceReadConfig8Response, ___E> for &'a DeviceReadConfig8Responsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceReadConfig8Response, ___E> for &'a DeviceReadConfig8Responsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceReadConfig8Response>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceReadConfig8Response>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceReadConfig8Response, ___E> for DeviceReadConfig8Responsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceReadConfig8Response, ___E> for DeviceReadConfig8Responsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceReadConfig8Response, DeviceReadConfig8Response>
const COPY_OPTIMIZATION: CopyOptimization<DeviceReadConfig8Response, DeviceReadConfig8Response>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceReadConfig8Response>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceReadConfig8Response>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, DeviceReadConfig8Response>, ___E> for &'a DeviceReadConfig8Responsewhere
___E: Encoder + ?Sized,
&'a DeviceReadConfig8Response: Encode<DeviceReadConfig8Response, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, DeviceReadConfig8Response>, ___E> for &'a DeviceReadConfig8Responsewhere
___E: Encoder + ?Sized,
&'a DeviceReadConfig8Response: Encode<DeviceReadConfig8Response, ___E>,
Sourcefn encode_option(
this: Option<&'a DeviceReadConfig8Response>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceReadConfig8Response>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a DeviceReadConfig8Response>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceReadConfig8Response>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, DeviceReadConfig8Response>, ___E> for DeviceReadConfig8Response
impl<___E> EncodeOption<Box<'static, DeviceReadConfig8Response>, ___E> for DeviceReadConfig8Response
Sourcefn encode_option(
this: Option<DeviceReadConfig8Response>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceReadConfig8Response>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<DeviceReadConfig8Response>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceReadConfig8Response>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<DeviceReadConfig8Response> for DeviceReadConfig8Response
impl FromWire<DeviceReadConfig8Response> for DeviceReadConfig8Response
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceReadConfig8Response, DeviceReadConfig8Response>
const COPY_OPTIMIZATION: CopyOptimization<DeviceReadConfig8Response, DeviceReadConfig8Response>
Sourcefn from_wire(wire: DeviceReadConfig8Response) -> DeviceReadConfig8Response
fn from_wire(wire: DeviceReadConfig8Response) -> DeviceReadConfig8Response
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceReadConfig8Response> for DeviceReadConfig8Response
impl FromWireRef<DeviceReadConfig8Response> for DeviceReadConfig8Response
Sourcefn from_wire_ref(wire: &DeviceReadConfig8Response) -> DeviceReadConfig8Response
fn from_wire_ref(wire: &DeviceReadConfig8Response) -> DeviceReadConfig8Response
Converts the given reference to this type.
Sourceimpl Hash for DeviceReadConfig8Response
impl Hash for DeviceReadConfig8Response
Sourceimpl Ord for DeviceReadConfig8Response
impl Ord for DeviceReadConfig8Response
Sourcefn cmp(&self, other: &DeviceReadConfig8Response) -> Ordering
fn cmp(&self, other: &DeviceReadConfig8Response) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeviceReadConfig8Response
impl PartialEq for DeviceReadConfig8Response
Sourcefn eq(&self, other: &DeviceReadConfig8Response) -> bool
fn eq(&self, other: &DeviceReadConfig8Response) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DeviceReadConfig8Response
impl PartialOrd for DeviceReadConfig8Response
impl Copy for DeviceReadConfig8Response
impl Eq for DeviceReadConfig8Response
impl StructuralPartialEq for DeviceReadConfig8Response