#[repr(C)]pub struct DeviceGetBtiRequest {
pub index: Uint32,
}Expand description
The wire type corresponding to DeviceGetBtiRequest.
Fields
index: Uint32Trait Implementations
Sourceimpl Clone for DeviceGetBtiRequest
impl Clone for DeviceGetBtiRequest
Sourcefn clone(&self) -> DeviceGetBtiRequest
fn clone(&self) -> DeviceGetBtiRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for DeviceGetBtiRequest
impl Constrained for DeviceGetBtiRequest
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, DeviceGetBtiRequest>,
_: <DeviceGetBtiRequest as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, DeviceGetBtiRequest>, _: <DeviceGetBtiRequest as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for DeviceGetBtiRequest
impl Debug for DeviceGetBtiRequest
Sourceimpl<___D> Decode<___D> for DeviceGetBtiRequestwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for DeviceGetBtiRequestwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<DeviceGetBtiRequest, ___E> for &'a DeviceGetBtiRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceGetBtiRequest, ___E> for &'a DeviceGetBtiRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetBtiRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetBtiRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceGetBtiRequest, ___E> for DeviceGetBtiRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceGetBtiRequest, ___E> for DeviceGetBtiRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetBtiRequest, DeviceGetBtiRequest>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetBtiRequest, DeviceGetBtiRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetBtiRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetBtiRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<DeviceGetBtiRequest, ___E> for DeviceGetBtiRequest<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
impl<___E, T0> Encode<DeviceGetBtiRequest, ___E> for DeviceGetBtiRequest<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetBtiRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetBtiRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceGetBtiRequest> for DeviceGetBtiRequest
impl FromWire<DeviceGetBtiRequest> for DeviceGetBtiRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetBtiRequest, DeviceGetBtiRequest>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetBtiRequest, DeviceGetBtiRequest>
Sourcefn from_wire(wire: DeviceGetBtiRequest) -> DeviceGetBtiRequest
fn from_wire(wire: DeviceGetBtiRequest) -> DeviceGetBtiRequest
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceGetBtiRequest> for DeviceGetBtiRequest
impl FromWireRef<DeviceGetBtiRequest> for DeviceGetBtiRequest
Sourcefn from_wire_ref(wire: &DeviceGetBtiRequest) -> DeviceGetBtiRequest
fn from_wire_ref(wire: &DeviceGetBtiRequest) -> DeviceGetBtiRequest
Converts the given reference to this type.
Sourceimpl IntoNatural for DeviceGetBtiRequest
impl IntoNatural for DeviceGetBtiRequest
Sourcetype Natural = DeviceGetBtiRequest
type Natural = DeviceGetBtiRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceGetBtiRequest
impl Wire for DeviceGetBtiRequest
Sourcetype Narrowed<'de> = DeviceGetBtiRequest
type Narrowed<'de> = DeviceGetBtiRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<DeviceGetBtiRequest>)
fn zero_padding(out_: &mut MaybeUninit<DeviceGetBtiRequest>)
Writes zeroes to the padding for this type, if any.