#[repr(C)]pub struct DeviceGetBtiResponse {
pub bti: Bti,
}Expand description
The wire type corresponding to DeviceGetBtiResponse.
Fields
bti: BtiTrait Implementations
Sourceimpl Constrained for DeviceGetBtiResponse
impl Constrained for DeviceGetBtiResponse
Sourceimpl Debug for DeviceGetBtiResponse
impl Debug for DeviceGetBtiResponse
Sourceimpl<___D> Decode<___D> for DeviceGetBtiResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for DeviceGetBtiResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<DeviceGetBtiResponse, ___E> for DeviceGetBtiResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<DeviceGetBtiResponse, ___E> for DeviceGetBtiResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetBtiResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetBtiResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetBtiResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetBtiResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<DeviceGetBtiResponse, ___E> for DeviceGetBtiResponse<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Bti, ___E>,
impl<___E, T0> Encode<DeviceGetBtiResponse, ___E> for DeviceGetBtiResponse<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Bti, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetBtiResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetBtiResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceGetBtiResponse> for DeviceGetBtiResponse
impl FromWire<DeviceGetBtiResponse> for DeviceGetBtiResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetBtiResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetBtiResponse, Self>
Sourcefn from_wire(wire: DeviceGetBtiResponse) -> Self
fn from_wire(wire: DeviceGetBtiResponse) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for DeviceGetBtiResponse
impl IntoNatural for DeviceGetBtiResponse
Sourcetype Natural = DeviceGetBtiResponse
type Natural = DeviceGetBtiResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceGetBtiResponse
impl Wire for DeviceGetBtiResponse
Sourcetype Narrowed<'de> = DeviceGetBtiResponse
type Narrowed<'de> = DeviceGetBtiResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.