#[repr(C)]pub struct DeviceGetDeviceInfoResponse {
pub info: DeviceInfo,
}Expand description
The wire type corresponding to DeviceGetDeviceInfoResponse.
Fields
info: DeviceInfoTrait Implementations
Sourceimpl Clone for DeviceGetDeviceInfoResponse
impl Clone for DeviceGetDeviceInfoResponse
Sourcefn clone(&self) -> DeviceGetDeviceInfoResponse
fn clone(&self) -> DeviceGetDeviceInfoResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for DeviceGetDeviceInfoResponse
impl Constrained for DeviceGetDeviceInfoResponse
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, DeviceGetDeviceInfoResponse>,
_: <DeviceGetDeviceInfoResponse as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, DeviceGetDeviceInfoResponse>, _: <DeviceGetDeviceInfoResponse as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for DeviceGetDeviceInfoResponse
impl Debug for DeviceGetDeviceInfoResponse
Sourceimpl<___D> Decode<___D> for DeviceGetDeviceInfoResponsewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for DeviceGetDeviceInfoResponsewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<DeviceGetDeviceInfoResponse, ___E> for &'a DeviceGetDeviceInfoResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceGetDeviceInfoResponse, ___E> for &'a DeviceGetDeviceInfoResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetDeviceInfoResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetDeviceInfoResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceGetDeviceInfoResponse, ___E> for DeviceGetDeviceInfoResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceGetDeviceInfoResponse, ___E> for DeviceGetDeviceInfoResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetDeviceInfoResponse, DeviceGetDeviceInfoResponse>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetDeviceInfoResponse, DeviceGetDeviceInfoResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetDeviceInfoResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetDeviceInfoResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<DeviceGetDeviceInfoResponse, ___E> for DeviceGetDeviceInfoResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<DeviceInfo, ___E>,
impl<___E, T0> Encode<DeviceGetDeviceInfoResponse, ___E> for DeviceGetDeviceInfoResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<DeviceInfo, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetDeviceInfoResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetDeviceInfoResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceGetDeviceInfoResponse> for DeviceGetDeviceInfoResponse
impl FromWire<DeviceGetDeviceInfoResponse> for DeviceGetDeviceInfoResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetDeviceInfoResponse, DeviceGetDeviceInfoResponse>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetDeviceInfoResponse, DeviceGetDeviceInfoResponse>
Sourcefn from_wire(wire: DeviceGetDeviceInfoResponse) -> DeviceGetDeviceInfoResponse
fn from_wire(wire: DeviceGetDeviceInfoResponse) -> DeviceGetDeviceInfoResponse
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceGetDeviceInfoResponse> for DeviceGetDeviceInfoResponse
impl FromWireRef<DeviceGetDeviceInfoResponse> for DeviceGetDeviceInfoResponse
Sourcefn from_wire_ref(
wire: &DeviceGetDeviceInfoResponse,
) -> DeviceGetDeviceInfoResponse
fn from_wire_ref( wire: &DeviceGetDeviceInfoResponse, ) -> DeviceGetDeviceInfoResponse
Converts the given reference to this type.
Sourceimpl IntoNatural for DeviceGetDeviceInfoResponse
impl IntoNatural for DeviceGetDeviceInfoResponse
Sourcetype Natural = DeviceGetDeviceInfoResponse
type Natural = DeviceGetDeviceInfoResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceGetDeviceInfoResponse
impl Wire for DeviceGetDeviceInfoResponse
Sourcetype Narrowed<'de> = DeviceGetDeviceInfoResponse
type Narrowed<'de> = DeviceGetDeviceInfoResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<DeviceGetDeviceInfoResponse>)
fn zero_padding(out_: &mut MaybeUninit<DeviceGetDeviceInfoResponse>)
Writes zeroes to the padding for this type, if any.