#[repr(C)]pub struct DeviceInfo {
pub vendor_id: Uint16,
pub device_id: Uint16,
pub base_class: u8,
pub sub_class: u8,
pub program_interface: u8,
pub revision_id: u8,
pub bus_id: u8,
pub dev_id: u8,
pub func_id: u8,
pub padding: Unit,
}Expand description
The wire type corresponding to DeviceInfo.
Fields
vendor_id: Uint16device_id: Uint16base_class: u8sub_class: u8program_interface: u8revision_id: u8bus_id: u8dev_id: u8func_id: u8padding: UnitTrait Implementations
Sourceimpl Clone for DeviceInfo
impl Clone for DeviceInfo
Sourcefn clone(&self) -> DeviceInfo
fn clone(&self) -> DeviceInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for DeviceInfo
impl Constrained for DeviceInfo
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, DeviceInfo>,
_: <DeviceInfo as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, DeviceInfo>, _: <DeviceInfo as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for DeviceInfo
impl Debug for DeviceInfo
Sourceimpl<___D> Decode<___D> for DeviceInfowhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for DeviceInfowhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<DeviceInfo, ___E> for &'a DeviceInfowhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceInfo, ___E> for &'a DeviceInfowhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceInfo>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceInfo>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceInfo, ___E> for DeviceInfowhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceInfo, ___E> for DeviceInfowhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceInfo, DeviceInfo>
const COPY_OPTIMIZATION: CopyOptimization<DeviceInfo, DeviceInfo>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceInfo>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceInfo>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0, T1, T2, T3, T4, T5, T6, T7, T8, T9> Encode<DeviceInfo, ___E> for DeviceInfo<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9>
impl<___E, T0, T1, T2, T3, T4, T5, T6, T7, T8, T9> Encode<DeviceInfo, ___E> for DeviceInfo<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceInfo>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceInfo>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceInfo> for DeviceInfo
impl FromWire<DeviceInfo> for DeviceInfo
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceInfo, DeviceInfo>
const COPY_OPTIMIZATION: CopyOptimization<DeviceInfo, DeviceInfo>
Sourcefn from_wire(wire: DeviceInfo) -> DeviceInfo
fn from_wire(wire: DeviceInfo) -> DeviceInfo
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceInfo> for DeviceInfo
impl FromWireRef<DeviceInfo> for DeviceInfo
Sourcefn from_wire_ref(wire: &DeviceInfo) -> DeviceInfo
fn from_wire_ref(wire: &DeviceInfo) -> DeviceInfo
Converts the given reference to this type.
Sourceimpl IntoNatural for DeviceInfo
impl IntoNatural for DeviceInfo
Sourcetype Natural = DeviceInfo
type Natural = DeviceInfo
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceInfo
impl Wire for DeviceInfo
Sourcetype Narrowed<'de> = DeviceInfo
type Narrowed<'de> = DeviceInfo
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<DeviceInfo>)
fn zero_padding(out_: &mut MaybeUninit<DeviceInfo>)
Writes zeroes to the padding for this type, if any.