#[repr(C)]pub struct DeviceMapInterruptResponse {
pub interrupt: Interrupt,
}Expand description
The wire type corresponding to DeviceMapInterruptResponse.
Fields
interrupt: InterruptTrait Implementations
Sourceimpl Constrained for DeviceMapInterruptResponse
impl Constrained for DeviceMapInterruptResponse
Sourceimpl Debug for DeviceMapInterruptResponse
impl Debug for DeviceMapInterruptResponse
Sourceimpl<___D> Decode<___D> for DeviceMapInterruptResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for DeviceMapInterruptResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<DeviceMapInterruptResponse, ___E> for DeviceMapInterruptResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<DeviceMapInterruptResponse, ___E> for DeviceMapInterruptResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceMapInterruptResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceMapInterruptResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceMapInterruptResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceMapInterruptResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<DeviceMapInterruptResponse, ___E> for DeviceMapInterruptResponse<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Interrupt, ___E>,
impl<___E, T0> Encode<DeviceMapInterruptResponse, ___E> for DeviceMapInterruptResponse<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Interrupt, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceMapInterruptResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceMapInterruptResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceMapInterruptResponse> for DeviceMapInterruptResponse
impl FromWire<DeviceMapInterruptResponse> for DeviceMapInterruptResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceMapInterruptResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceMapInterruptResponse, Self>
Sourcefn from_wire(wire: DeviceMapInterruptResponse) -> Self
fn from_wire(wire: DeviceMapInterruptResponse) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for DeviceMapInterruptResponse
impl IntoNatural for DeviceMapInterruptResponse
Sourcetype Natural = DeviceMapInterruptResponse
type Natural = DeviceMapInterruptResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceMapInterruptResponse
impl Wire for DeviceMapInterruptResponse
Sourcetype Narrowed<'de> = DeviceMapInterruptResponse
type Narrowed<'de> = DeviceMapInterruptResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.