#[repr(C)]pub struct DeviceReadConfig16Response {
pub value: Uint16,
}Expand description
The wire type corresponding to DeviceReadConfig16Response.
Fields
value: Uint16Trait Implementations
Sourceimpl Clone for DeviceReadConfig16Response
impl Clone for DeviceReadConfig16Response
Sourcefn clone(&self) -> DeviceReadConfig16Response
fn clone(&self) -> DeviceReadConfig16Response
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for DeviceReadConfig16Response
impl Constrained for DeviceReadConfig16Response
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, DeviceReadConfig16Response>,
_: <DeviceReadConfig16Response as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, DeviceReadConfig16Response>, _: <DeviceReadConfig16Response as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for DeviceReadConfig16Response
impl Debug for DeviceReadConfig16Response
Sourceimpl<___D> Decode<___D> for DeviceReadConfig16Responsewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for DeviceReadConfig16Responsewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<DeviceReadConfig16Response, ___E> for &'a DeviceReadConfig16Responsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceReadConfig16Response, ___E> for &'a DeviceReadConfig16Responsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceReadConfig16Response>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceReadConfig16Response>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceReadConfig16Response, ___E> for DeviceReadConfig16Responsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceReadConfig16Response, ___E> for DeviceReadConfig16Responsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceReadConfig16Response, DeviceReadConfig16Response>
const COPY_OPTIMIZATION: CopyOptimization<DeviceReadConfig16Response, DeviceReadConfig16Response>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceReadConfig16Response>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceReadConfig16Response>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<DeviceReadConfig16Response, ___E> for DeviceReadConfig16Response<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint16, ___E>,
impl<___E, T0> Encode<DeviceReadConfig16Response, ___E> for DeviceReadConfig16Response<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint16, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceReadConfig16Response>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceReadConfig16Response>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceReadConfig16Response> for DeviceReadConfig16Response
impl FromWire<DeviceReadConfig16Response> for DeviceReadConfig16Response
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceReadConfig16Response, DeviceReadConfig16Response>
const COPY_OPTIMIZATION: CopyOptimization<DeviceReadConfig16Response, DeviceReadConfig16Response>
Sourcefn from_wire(wire: DeviceReadConfig16Response) -> DeviceReadConfig16Response
fn from_wire(wire: DeviceReadConfig16Response) -> DeviceReadConfig16Response
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceReadConfig16Response> for DeviceReadConfig16Response
impl FromWireRef<DeviceReadConfig16Response> for DeviceReadConfig16Response
Sourcefn from_wire_ref(
wire: &DeviceReadConfig16Response,
) -> DeviceReadConfig16Response
fn from_wire_ref( wire: &DeviceReadConfig16Response, ) -> DeviceReadConfig16Response
Converts the given reference to this type.
Sourceimpl IntoNatural for DeviceReadConfig16Response
impl IntoNatural for DeviceReadConfig16Response
Sourcetype Natural = DeviceReadConfig16Response
type Natural = DeviceReadConfig16Response
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceReadConfig16Response
impl Wire for DeviceReadConfig16Response
Sourcetype Narrowed<'de> = DeviceReadConfig16Response
type Narrowed<'de> = DeviceReadConfig16Response
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<DeviceReadConfig16Response>)
fn zero_padding(out_: &mut MaybeUninit<DeviceReadConfig16Response>)
Writes zeroes to the padding for this type, if any.