#[repr(C)]pub struct ExtendedCapability {
pub id: Uint16,
pub offset: Uint16,
}Expand description
The wire type corresponding to ExtendedCapability.
Fields
id: Uint16offset: Uint16Trait Implementations
Sourceimpl Clone for ExtendedCapability
impl Clone for ExtendedCapability
Sourcefn clone(&self) -> ExtendedCapability
fn clone(&self) -> ExtendedCapability
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for ExtendedCapability
impl Constrained for ExtendedCapability
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, ExtendedCapability>,
_: <ExtendedCapability as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, ExtendedCapability>, _: <ExtendedCapability as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for ExtendedCapability
impl Debug for ExtendedCapability
Sourceimpl<___D> Decode<___D> for ExtendedCapabilitywhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for ExtendedCapabilitywhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<ExtendedCapability, ___E> for &'a ExtendedCapabilitywhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<ExtendedCapability, ___E> for &'a ExtendedCapabilitywhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ExtendedCapability>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ExtendedCapability>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ExtendedCapability, ___E> for ExtendedCapabilitywhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<ExtendedCapability, ___E> for ExtendedCapabilitywhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ExtendedCapability, ExtendedCapability>
const COPY_OPTIMIZATION: CopyOptimization<ExtendedCapability, ExtendedCapability>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ExtendedCapability>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ExtendedCapability>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0, T1> Encode<ExtendedCapability, ___E> for ExtendedCapability<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint16, ___E>,
T1: Encode<Uint16, ___E>,
impl<___E, T0, T1> Encode<ExtendedCapability, ___E> for ExtendedCapability<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint16, ___E>,
T1: Encode<Uint16, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ExtendedCapability>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ExtendedCapability>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<ExtendedCapability> for ExtendedCapability
impl FromWire<ExtendedCapability> for ExtendedCapability
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ExtendedCapability, ExtendedCapability>
const COPY_OPTIMIZATION: CopyOptimization<ExtendedCapability, ExtendedCapability>
Sourcefn from_wire(wire: ExtendedCapability) -> ExtendedCapability
fn from_wire(wire: ExtendedCapability) -> ExtendedCapability
Converts the given owned value to this type.
Sourceimpl FromWireRef<ExtendedCapability> for ExtendedCapability
impl FromWireRef<ExtendedCapability> for ExtendedCapability
Sourcefn from_wire_ref(wire: &ExtendedCapability) -> ExtendedCapability
fn from_wire_ref(wire: &ExtendedCapability) -> ExtendedCapability
Converts the given reference to this type.
Sourceimpl IntoNatural for ExtendedCapability
impl IntoNatural for ExtendedCapability
Sourcetype Natural = ExtendedCapability
type Natural = ExtendedCapability
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for ExtendedCapability
impl Wire for ExtendedCapability
Sourcetype Narrowed<'de> = ExtendedCapability
type Narrowed<'de> = ExtendedCapability
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<ExtendedCapability>)
fn zero_padding(out_: &mut MaybeUninit<ExtendedCapability>)
Writes zeroes to the padding for this type, if any.