#[repr(C)]pub struct InterruptModes {
pub has_legacy: bool,
pub msi_count: u8,
pub msix_count: Uint16,
}Expand description
The wire type corresponding to InterruptModes.
Fields
has_legacy: boolmsi_count: u8msix_count: Uint16Trait Implementations
Sourceimpl Clone for InterruptModes
impl Clone for InterruptModes
Sourcefn clone(&self) -> InterruptModes
fn clone(&self) -> InterruptModes
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for InterruptModes
impl Constrained for InterruptModes
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, InterruptModes>,
_: <InterruptModes as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, InterruptModes>, _: <InterruptModes as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for InterruptModes
impl Debug for InterruptModes
Sourceimpl<___D> Decode<___D> for InterruptModeswhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for InterruptModeswhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<InterruptModes, ___E> for &'a InterruptModeswhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<InterruptModes, ___E> for &'a InterruptModeswhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InterruptModes>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InterruptModes>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<InterruptModes, ___E> for InterruptModeswhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<InterruptModes, ___E> for InterruptModeswhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<InterruptModes, InterruptModes>
const COPY_OPTIMIZATION: CopyOptimization<InterruptModes, InterruptModes>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InterruptModes>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InterruptModes>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0, T1, T2> Encode<InterruptModes, ___E> for InterruptModes<T0, T1, T2>
impl<___E, T0, T1, T2> Encode<InterruptModes, ___E> for InterruptModes<T0, T1, T2>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InterruptModes>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InterruptModes>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<InterruptModes> for InterruptModes
impl FromWire<InterruptModes> for InterruptModes
Sourceconst COPY_OPTIMIZATION: CopyOptimization<InterruptModes, InterruptModes>
const COPY_OPTIMIZATION: CopyOptimization<InterruptModes, InterruptModes>
Sourcefn from_wire(wire: InterruptModes) -> InterruptModes
fn from_wire(wire: InterruptModes) -> InterruptModes
Converts the given owned value to this type.
Sourceimpl FromWireRef<InterruptModes> for InterruptModes
impl FromWireRef<InterruptModes> for InterruptModes
Sourcefn from_wire_ref(wire: &InterruptModes) -> InterruptModes
fn from_wire_ref(wire: &InterruptModes) -> InterruptModes
Converts the given reference to this type.
Sourceimpl IntoNatural for InterruptModes
impl IntoNatural for InterruptModes
Sourcetype Natural = InterruptModes
type Natural = InterruptModes
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for InterruptModes
impl Wire for InterruptModes
Sourcetype Narrowed<'de> = InterruptModes
type Narrowed<'de> = InterruptModes
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<InterruptModes>)
fn zero_padding(out_: &mut MaybeUninit<InterruptModes>)
Writes zeroes to the padding for this type, if any.